## Publications & Presentations

* [Hereditary Stratigraphy Methods for Phylogenetic Inference over Distributed EC Populations](https://github.com/mmore500/hstrat-recomb-concept/releases/latest) at [GPTP 2023](https://web.archive.org/web/20230516045339/http://gptp-workshop.com/)

<iframe width="560" height="315" src="https://www.youtube.com/embed/-pRSWX0shT0" title="YouTube video player" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>

* [Hereditary Stratigraphy: Genome Annotations to Enable Phylogenetic Inference over Distributed Populations](https://github.com/mmore500/hereditary-stratigraph-concept/releases/tag/v0.3.0) at [Artificial Life 2022](https://2022.alife.org/)

<iframe width="560" height="315" src="https://www.youtube.com/embed/-HJYNrafLpo" title="YouTube video player" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>

* [Conduit: A C++ Library for Best-Effort High Performance Computing](https://github.com/mmore500/hereditary-stratigraph-concept/releases/tag/v0.2.0) at [GECCO 2022](https://gecco-2022.sigevo.org/)

<iframe width="560" height="315" src="https://www.youtube.com/embed/lf3NdcKOZ2c" title="YouTube video player" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>
